@@ -398,11 +398,6 @@ class GUI(Tk):
 				music.play(0)
 			time.sleep(.5-np.min(((time.time()-t),.5)))
 		time.sleep(1)
-		try:
-			os.remove(fn_midi)
-			os.remove(fn_wav)
-		except:
-			pass
 		self.refresh_GUI()
 		
 	def write_audio(self):
